==> cr12g-panhuo-impl-3.0.0-20210823.074632-130-sources.jar: com/ejianc/business/asset/bean/PlanDetailEntity.java <==
package com.ejianc.business.asset.bean;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 计划实体明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_panhuo_plan_detail")
public class PlanDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="plan_id")
    private java.lang.Long planId; // 主表主键ID
    @TableField(value="material_id")
    private java.lang.Long materialId; // 物资主键
    @TableField(value="material_name")
    private java.lang.String materialName; // 物资名称
    @TableField(value="material_type_id")
    private java.lang.Long materialTypeId; // 物资类别
    @TableField(value="material_type_name")
    private java.lang.String materialTypeName; // 物资类别名称
    @TableField(value="material_code")
    private java.lang.String materialCode; // 物料编码
    @TableField(value="unit")
    private java.lang.String unit; // 单位
    @TableField(value="spec")
    private java.lang.String spec; // 规格型号
    @TableField(value="nums")
    private java.math.BigDecimal nums; // 需求数量
    @TableField(value="memo")
    private java.lang.String memo; // 备注
    @TableField(value="material_type_code")
    private java.lang.String materialTypeCode; // 物资类别编号
    @TableField(value="asset_type")
    private java.lang.Integer assetType; // 物资类型 0-周转材，1-台车
    @TableField(value="capacity")
    private java.math.BigDecimal capacity; // 承载量
    @TableField(value="guide_price")
    private java.math.BigDecimal guidePrice; // 指导价
    @TableField(value="belong_project_name")
    private java.lang.String belongProjectName; // 物资所在项目

    @TableField(value="sum_nums")
    private java.math.BigDecimal sumNums; // 累计验收数量

    public BigDecimal getSumNums() {
        return sumNums;
    }

    public void setSumNums(BigDecimal sumNums) {
        this.sumNums = sumNums;
    }

    /**
     * 主表主键ID
     */
    public java.lang.Long getPlanId() {
        return planId;
    }

    /**
     * 主表主键ID
     */
    public void setPlanId(java.lang.Long planId) {
        this.planId = planId;
    }
    /**
     * 物资主键
     */
    public java.lang.Long getMaterialId() {
        return materialId;
    }

    /**
     * 物资主键
     */
    public void setMaterialId(java.lang.Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 物资名称
     */
    public java.lang.String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(java.lang.String materialName) {
        this.materialName = materialName;
    }
    /**
     * 物资类别
     */
    public java.lang.Long getMaterialTypeId() {
        return materialTypeId;
    }

    /**
     * 物资类别
     */
    public void setMaterialTypeId(java.lang.Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    /**
     * 物资类别名称
     */
    public java.lang.String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 物资类别名称
     */
    public void setMaterialTypeName(java.lang.String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 物料编码
     */
    public java.lang.String getMaterialCode() {
        return materialCode;
    }

    /**
     * 物料编码
     */
    public void setMaterialCode(java.lang.String materialCode) {
        this.materialCode = materialCode;
    }
    /**
     * 单位
     */
    public java.lang.String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(java.lang.String unit) {
        this.unit = unit;
    }
    /**
     * 规格型号
     */
    public java.lang.String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(java.lang.String spec) {
        this.spec = spec;
    }
    /**
     * 需求数量
     */
    public java.math.BigDecimal getNums() {
        return nums;
    }

    /**
     * 需求数量
     */
    public void setNums(java.math.BigDecimal nums) {
        this.nums = nums;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 物资类别编号
     */
    public java.lang.String getMaterialTypeCode() {
        return materialTypeCode;
    }

    /**
     * 物资类别编号
     */
    public void setMaterialTypeCode(java.lang.String materialTypeCode) {
        this.materialTypeCode = materialTypeCode;
    }
    /**
     * 物资类型 0-周转材，1-台车
     */
    public java.lang.Integer getAssetType() {
        return assetType;
    }

    /**
     * 物资类型 0-周转材，1-台车
     */
    public void setAssetType(java.lang.Integer assetType) {
        this.assetType = assetType;
    }
    /**
     * 承载量
     */
    public java.math.BigDecimal getCapacity() {
        return capacity;
    }

    /**
     * 承载量
     */
    public void setCapacity(java.math.BigDecimal capacity) {
        this.capacity = capacity;
    }
    /**
     * 指导价
     */
    public java.math.BigDecimal getGuidePrice() {
        return guidePrice;
    }

    /**
     * 指导价
     */
    public void setGuidePrice(java.math.BigDecimal guidePrice) {
        this.guidePrice = guidePrice;
    }
    /**
     * 物资所在项目
     */
    public java.lang.String getBelongProjectName() {
        return belongProjectName;
    }

    /**
     * 物资所在项目
     */
    public void setBelongProjectName(java.lang.String belongProjectName) {
        this.belongProjectName = belongProjectName;
    }

}

==> cr12g-panhuo-impl-3.0.0-20210917.163558-197-sources.jar: com/ejianc/business/asset/bean/PlanDetailEntity.java <==
package com.ejianc.business.asset.bean;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 计划实体明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_panhuo_plan_detail")
public class PlanDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="plan_id")
    private java.lang.Long planId; // 主表主键ID
    @TableField(value="material_id")
    private java.lang.Long materialId; // 物资主键
    @TableField(value="material_name")
    private java.lang.String materialName; // 物资名称
    @TableField(value="material_type_id")
    private java.lang.Long materialTypeId; // 物资类别
    @TableField(value="material_type_name")
    private java.lang.String materialTypeName; // 物资类别名称
    @TableField(value="material_code")
    private java.lang.String materialCode; // 物料编码
    @TableField(value="unit")
    private java.lang.String unit; // 单位
    @TableField(value="spec")
    private java.lang.String spec; // 规格型号
    @TableField(value="nums")
    private java.math.BigDecimal nums; // 需求数量
    @TableField(value="memo")
    private java.lang.String memo; // 备注
    @TableField(value="material_type_code")
    private java.lang.String materialTypeCode; // 物资类别编号
    @TableField(value="asset_type")
    private java.lang.Integer assetType; // 物资类型 0-周转材，1-台车
    @TableField(value="asset_type_name")
    private java.lang.String assetTypeName; // 物资类型 0-周转材，1-台车
    @TableField(value="capacity")
    private java.math.BigDecimal capacity; // 承载量
    @TableField(value="guide_price")
    private java.math.BigDecimal guidePrice; // 指导价
    @TableField(value="belong_project_name")
    private java.lang.String belongProjectName; // 物资所在项目

    @TableField(value="sum_nums")
    private java.math.BigDecimal sumNums; // 累计验收数量

    public BigDecimal getSumNums() {
        return sumNums;
    }

    public void setSumNums(BigDecimal sumNums) {
        this.sumNums = sumNums;
    }

    public String getAssetTypeName() {
        return assetTypeName;
    }

    public void setAssetTypeName(String assetTypeName) {
        this.assetTypeName = assetTypeName;
    }

    /**
     * 主表主键ID
     */
    public java.lang.Long getPlanId() {
        return planId;
    }

    /**
     * 主表主键ID
     */
    public void setPlanId(java.lang.Long planId) {
        this.planId = planId;
    }
    /**
     * 物资主键
     */
    public java.lang.Long getMaterialId() {
        return materialId;
    }

    /**
     * 物资主键
     */
    public void setMaterialId(java.lang.Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 物资名称
     */
    public java.lang.String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(java.lang.String materialName) {
        this.materialName = materialName;
    }
    /**
     * 物资类别
     */
    public java.lang.Long getMaterialTypeId() {
        return materialTypeId;
    }

    /**
     * 物资类别
     */
    public void setMaterialTypeId(java.lang.Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    /**
     * 物资类别名称
     */
    public java.lang.String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 物资类别名称
     */
    public void setMaterialTypeName(java.lang.String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 物料编码
     */
    public java.lang.String getMaterialCode() {
        return materialCode;
    }

    /**
     * 物料编码
     */
    public void setMaterialCode(java.lang.String materialCode) {
        this.materialCode = materialCode;
    }
    /**
     * 单位
     */
    public java.lang.String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(java.lang.String unit) {
        this.unit = unit;
    }
    /**
     * 规格型号
     */
    public java.lang.String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(java.lang.String spec) {
        this.spec = spec;
    }
    /**
     * 需求数量
     */
    public java.math.BigDecimal getNums() {
        return nums;
    }

    /**
     * 需求数量
     */
    public void setNums(java.math.BigDecimal nums) {
        this.nums = nums;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 物资类别编号
     */
    public java.lang.String getMaterialTypeCode() {
        return materialTypeCode;
    }

    /**
     * 物资类别编号
     */
    public void setMaterialTypeCode(java.lang.String materialTypeCode) {
        this.materialTypeCode = materialTypeCode;
    }
    /**
     * 物资类型 0-周转材，1-台车
     */
    public java.lang.Integer getAssetType() {
        return assetType;
    }

    /**
     * 物资类型 0-周转材，1-台车
     */
    public void setAssetType(java.lang.Integer assetType) {
        this.assetType = assetType;
    }
    /**
     * 承载量
     */
    public java.math.BigDecimal getCapacity() {
        return capacity;
    }

    /**
     * 承载量
     */
    public void setCapacity(java.math.BigDecimal capacity) {
        this.capacity = capacity;
    }
    /**
     * 指导价
     */
    public java.math.BigDecimal getGuidePrice() {
        return guidePrice;
    }

    /**
     * 指导价
     */
    public void setGuidePrice(java.math.BigDecimal guidePrice) {
        this.guidePrice = guidePrice;
    }
    /**
     * 物资所在项目
     */
    public java.lang.String getBelongProjectName() {
        return belongProjectName;
    }

    /**
     * 物资所在项目
     */
    public void setBelongProjectName(java.lang.String belongProjectName) {
        this.belongProjectName = belongProjectName;
    }

}
